# -*- coding: utf-8 -*-

import json

import click

from em_tasks.utils.offer_services import AmzOfferService
from em_tasks.utils.amz_products_analyzer import AmzProductsAnalyzer
from em_tasks.store.models import *

from em_celery import logger, init_db, get_config, get_amz_offer_filter_config, get_offer_service_config, get_product_service


@click.command('Analyze Amazon products.')
@click.option('-m', '--marketplace', required=True, type=str, default='us', help='Amazon marketplace.')
@click.option('-o', '--output_path', required=True, type=str, help='Output file path')
@click.argument('asins_path')
def analyze_products(asins_path, output_path, marketplace='us'):
  init_db()

  output_path = os.path.abspath(os.path.expanduser(output_path))
  output_dir = os.path.dirname(output_path)
  if not os.path.isdir(output_dir):
    os.makedirs(output_dir)

  marketplace = marketplace.lower()
  filter_cond = get_amz_offer_filter_config(marketplace)
  offer_service_cfg = get_offer_service_config()
  offer_service = AmzOfferService(
    offer_service_cfg['host'], offer_service_cfg['port'],
    offer_service_cfg['user'], offer_service_cfg['password'], filter_cond)

  logger.info('[OfferFilters] %s', filter_cond)

  product_service = get_product_service()

  products_filter = AmzProductsAnalyzer(marketplace, product_service, offer_service, asins_path, output_path)
  products_filter.run()
  logger.info('[AnalyzeStats] {}'.format(products_filter.get_stats()))


if __name__ == "__main__":
  analyze_products()
