# -*- coding: utf-8 -*-

import json

import click

from tracking_tracker.ups_api import UPSApi
from tracking_tracker.fedex_api import FedexApi
from usps import USPSApi, USPSApiError

from em_tasks.store.store_util import StoreUtil
from em_tasks.tools.shipment_updater import ShipmentUpdater
from em_tasks.store.models import *

from em_celery import logger, init_db, get_config


@click.command('Update FBA Shipments')
@click.option('-s', '--store_code', required=True, type=str, help='Store code.')
@click.option('-sid', '--spreadsheet_id', required=True, type=str, help='Spreadsheet ID.')
def update_shipments(store_code, spreadsheet_id):
  init_db()

  store = StoreUtil.get_store_by_code(store_code)
  if not store:
    logger.warning('[StoreNotFound] %s', store_code)
    return

  cfg = get_config()

  ups_api = None
  ups_cfg = cfg.get('ups', None)
  if ups_cfg:
    merchant_id = ups_cfg.get('merchant_id', None)
    client_id = ups_cfg.get('client_id', None)
    client_secret = ups_cfg.get('client_secret', None)
    environment = ups_cfg.get('environment', 'production')
    ups_api = UPSApi(merchant_id, client_id, client_secret, environment)

  fedex_api = None
  fedex_cfg = cfg.get('fedex', None)
  if fedex_cfg:
    client_id = fedex_cfg.get('client_id', None)
    client_secret = fedex_cfg.get('client_secret', None)
    environment = fedex_cfg.get('environment', 'production')
    grant_type = fedex_cfg.get('grant_type', 'client_credentials')
    fedex_api = FedexApi(client_id, client_secret, environment, grant_type)

  usps_api = None
  usps_cfg = cfg.get('usps', None)
  if usps_cfg:
    user_id = usps_cfg.get('user_id', None)
    api = USPSApi(user_id)

  service_account_data = json.loads(store.service_account_data)
  updater = ShipmentUpdater(service_account_data, spreadsheet_id, ups_api, fedex_api, usps_api)
  updater.run()

if __name__ == "__main__":
  update_shipments()
