# -*- coding: utf-8 -*-

import json

import click

from em_tasks.utils.price_calculator import PriceCalculator
from em_tasks.tools.shopify_dangdang_exporter import ShopifyDangdangProductsExporter
from em_tasks.store.models import *

from em_celery import logger, init_db, get_config, get_product_service


@click.command('Export Dangdang products.')
@click.option('-o', '--output_path', required=True, type=str, help='Output file path')
def export_products(output_path):
  init_db()

  output_path = os.path.abspath(os.path.expanduser(output_path))
  output_dir = os.path.dirname(output_path)
  if not os.path.isdir(output_dir):
    os.makedirs(output_dir)

  price_rules = {
    'roi': 0.5,
    'ad_cost': 5,
    'transfer_cost': 12
  }

  cfg = get_config()
  price_rules_cfg = cfg.get('price.rules.dangdang', dict())
  for k, v in price_rules_cfg.items():
    price_rules[k] = round(float(v), 2)
  price_calculator = PriceCalculator(price_rules)

  product_service = get_product_service()

  exporter = ShopifyDangdangProductsExporter(product_service, price_calculator, output_path)
  exporter.run()


if __name__ == "__main__":
  export_products()
