# -*- coding: utf-8 -*-

import json

import click

from em_tasks.utils.price_calculator import PriceCalculator
from em_tasks.tools.shopify_ebay_exporter import ShopifyEbayProductsExporter
from em_tasks.store.models import *

from em_celery import logger, init_db, get_config, get_product_service


@click.command('Export Ebay products.')
@click.option('-m', '--marketplace', required=True, type=str, default='us', help='Ebay marketplace.')
@click.option('-o', '--output_path', required=True, type=str, help='Output file path')
def export_products(output_path, marketplace='us'):
  init_db()

  output_path = os.path.abspath(os.path.expanduser(output_path))
  output_dir = os.path.dirname(output_path)
  if not os.path.isdir(output_dir):
    os.makedirs(output_dir)

  price_rules = {
    'roi': 0.3,
    'ad_cost': 5,
    'transfer_cost': 5
  }

  marketplace = marketplace.lower()
  cfg = get_config()
  price_rules_cfg = cfg.get('price.rules.ebay_{}'.format(marketplace), dict())
  for k, v in price_rules_cfg.items():
    price_rules[k] = round(float(v), 2)
  price_calculator = PriceCalculator(price_rules)

  product_service = get_product_service()

  exporter = ShopifyEbayProductsExporter(marketplace, product_service, price_calculator, output_path)
  exporter.run()


if __name__ == "__main__":
  export_products()
