# -*- coding: utf-8 -*-

import json

import click

from em_tasks.utils.offer_services import AmzOfferService
from em_tasks.utils.price_calculator import PriceCalculator
from em_tasks.tools.amz_uploadable_products_filter import AmzUploadableProductsFilter
from em_tasks.store.models import *

from em_celery import logger, init_db, get_config, get_amz_offer_filter_config, get_offer_service_config, get_product_service


@click.command('Filter Amazon uploadable product from Spapi.')
@click.option('-s', '--store_code', required=True, type=str)
@click.option('-mf', '--from_marketplace', required=True, type=str, default='us', help='Amazon marketplace of products from.')
@click.option('-mt', '--to_marketplace', required=True, type=str, default='uk', help='Amazon marketplace of products to.')
@click.option('-o', '--output_path', required=True, type=str, help='Output file path')
@click.argument('products_path')
def filter_products(store_code, products_path, output_path, from_marketplace='us', to_marketplace='uk'):
  init_db()

  products_path = os.path.abspath(os.path.expanduser(products_path))
  if not os.path.isfile(products_path):
    logger.error("Could not find products file - %s", products_path)
    return

  output_path = os.path.abspath(os.path.expanduser(output_path))
  output_dir = os.path.dirname(output_path)
  if not os.path.isdir(output_dir):
    os.makedirs(output_dir)

  from_marketplace = from_marketplace.lower()
  to_marketplace = to_marketplace.lower()

  filter_cond = get_amz_offer_filter_config()
  offer_service_cfg = get_offer_service_config()
  offer_service = AmzOfferService(
    offer_service_cfg['host'], offer_service_cfg['port'],
    offer_service_cfg['user'], offer_service_cfg['password'], filter_cond)

  price_rules = {
    'roi': 0.3,
    'ad_cost': 4.5,
    'transfer_cost': 12
  }

  cfg = get_config()
  price_rules_cfg = cfg.get('price.rules.amz_{}_{}'.format(from_marketplace, to_marketplace), dict())
  for k, v in price_rules_cfg.items():
    price_rules[k] = round(float(v), 2)
  price_calculator = PriceCalculator(price_rules)

  product_service = get_product_service()

  products_filter = AmzUploadableProductsFilter(store_code, from_marketplace, to_marketplace, product_service, offer_service, price_calculator, products_path, output_path)
  products_filter.run()


if __name__ == "__main__":
  filter_products()
