# -*- coding: utf-8 -*-

import re
import json

import click

from em_tasks.store.store_util import StoreUtil
from em_tasks.spree.product_util import ProductUtil
from em_tasks.store.models import *

from em_celery import logger, init_db, get_config, get_amz_offer_filter_config, get_offer_service_config


@click.command('Filter Coupang products')
@click.option('-s', '--store_code', required=True, type=str, help='Store code.')
@click.option('-o', '--output_path', required=True, type=str)
def filter_coupang_products(store_code, output_path):
  init_db()

  filter_patterns = [
    r'(.*?Food.*?)',
    r'(.*?Juice.*?)',
    r'(.*?Fresh.*?)',
    r'(.*?Drink.*?)',
    r'(.*?Refrigerate.*?)',
    r'(.*?Grill.*?)',
    r'(.*?Meat.*?)',
    r'(.*?Fruit.*?)',
    r'(.*?Beef.*?)',
    r'(.*?Pork.*?)',
    r'(.*?Chicken.*?)',
    r'(.*?mushroom.*?)',
    r'(.*?blueberry.*?)',
    r'(.*?Broccoli.*?)',
    r'(.*?Ginger.*?)',
    r'(.*?Tomato.*?)',
    r'(.*?Sunflower.*?)',
    r'(.*?pepper.*?)',
    r'(.*?Hanspoon.*?)',
    r'(.*?Orange.*?)',
    r'(.*?Pumpkin.*?)',
    r'(.*?onion.*?)',
    r'(.*?Potato.*?)',
    r'(.*?Ginseng.*?)',
    r'(.*?tofu.*?)',
    r'(.*?Primrose Oil.*?)',
    r'(.*?California Gold Nutrition.*?)',
    r'(.*?American Health Royal.*?)',
    r'(.*?Nutritional.*?)',
    r'(.*?Hongseong.*?)',
    r'(.*?belt massager.*?)',
    r'(.*?frozen.*?)',
    r'(.*?kg.*?)',
    r'(.*?Large.*?)',
    r'(.*?Heavy.*?)',
    r'(.*?HOMETLOVE.*?)',
    r'(.*?Ballet Bar.*?)',
    r'(.*?cans.*?)',
    r'(.*?Fragrance.*?)',
    r'(.*?Spray.*?)',
    r'(.*?Shampoo.*?)',
    r'(.*?OneTwoFit.*?)',
    r'(.*?Hanwoo.*?)',
    r'(.*?Chaekkeut.*?)',
    r'(.*?Chamyewoo.*?)',
    r'(.*?Pollack.*?)',
    r'(.*?Apple.*?)',
    r'(.*?Philips.*?)',
    r'(.*?recharge.*?)',
  ]

  to_del = []
  batch_size = 2500
  product_ids = []
  store = StoreUtil.get_store_by_code(store_code)
  credential = json.loads(store.api_credential)
  product_util = ProductUtil(credential['endpoint'], credential['api_key'], credential.get('api_version', 'v1'))
  for prod in product_util.get_coupang_products():
    product_ids.append(prod['product_id'].strip())
    if len(product_ids) < batch_size:
      continue

    for product in Product.select(Product.id, Product.name).where(Product.id.in_(product_ids)).execute():
      title = product.name

      matched = False
      for pattern in filter_patterns:
        matched = re.search(pattern, title, flags=re.IGNORECASE)
        if matched:
          break
      if matched:
        print('[InvalidProduct] %s' % title)
        to_del.append(str(product.id))

    product_ids = []

  if product_ids:
    for product in Product.select(Product.id, Product.name).where(Product.id.in_(product_ids)).execute():
      title = product.name

      matched = False
      for pattern in filter_patterns:
        matched = re.search(pattern, title, flags=re.IGNORECASE)
        if matched:
          break
      if matched:
        print('[InvalidProduct] %s' % title)
        to_del.append(str(product.id))

    product_ids = []

  print('[ProductTotal] %s' % len(to_del))
  with open(output_path, 'w+', encoding='utf-8', errors='ignore') as fh:
    fh.write("\n".join(to_del))


if __name__ == '__main__':
  filter_coupang_products()
