# -*- coding: utf-8 -*-

import datetime
import json

import click

from em_celery import logger, init_db
from em_tasks.store.store_util import StoreUtil
from em_tasks.spree.order_util import OrderUtil
from em_tasks.store.models import *


@click.command('Capture fulfilled Spree Orders')
@click.option('-s', '--store_code', required=True, type=str, help='Store code.')
@click.option('-d', '--days', type=int, default=21, help='Capture how many days fulfilled orders, default is 21.')
def capture_orders(store_code, days=14):
  init_db()

  store = StoreUtil.get_store_by_code(store_code)
  if not store:
    logger.warning('[StoreNotFound] %s', store_code)
    return

  credential = json.loads(store.api_credential)
  order_util = OrderUtil(credential['endpoint'], credential['api_key'], credential.get('api_version', 'v1'))
  # order_util = OrderUtil('http://localhost:3000', credential['api_key'], credential.get('api_version', 'v1'))
  order_util.capture_fulfilled_orders(days)


if __name__ == "__main__":
  capture_orders()
