# -*- coding: utf-8 -*-

import datetime
import json

import click

from em_celery import logger, init_db
from em_tasks.utils.price_calculator import PriceCalculator
from em_tasks.store.store_util import StoreUtil
from em_tasks.spree.order_util import OrderUtil
from em_tasks.utils.pipelines.price_calculator import PriceCalculatorPipeline
from em_tasks.store.models import *

from em_celery import logger, get_config, init_db, get_product_service


@click.command('Format products to Spree style')
@click.option('-s', '--source', required=True, type=str, help='Product source.')
@click.option('-sc', '--source_code', required=True, type=str, help='Product source code.')
@click.option('-ms', '--min_shipping_days', type=int, default=7, help='Minimum shipping days, default is 7.')
@click.option('-tn', '--taxonomy_name', type=str, default='Categories', help='Spree taxonomy name, default is "Categories".')
@click.option('-m', '--merchant_id', required=True, type=str, help='Google Merchant ID to upload to.')
@click.option('-v', '--vendor_id', required=True, type=str, help='Vendor ID that products belongs to.')
@click.option('-tc', '--tax_category_id', type=int, default=1, help='Spree tax category ID.')
@click.option('-sl', '--stock_location_id', required=True, type=int, help='Spree stock location ID.')
@click.option('-sc_id', '--shipping_category_id', required=True, type=int, help='Spree shipping category ID.')
@click.option('-o', '--output_path', required=True, type=str)
@click.argument('products_path')
def format_products(products_path, output_path, source, shipping_category_id, stock_location_id, merchant_id, vendor_id, tax_category_id=1, taxonomy_name='Categories', min_shipping_days=7):
  init_db()

  if not products_path or not output_path:
    return

  products_path = os.path.abspath(os.path.expanduser(products_path))
  if not os.path.isfile(products_path):
    return

  output_path = os.path.abspath(os.path.expanduser(output_path))
  output_dir = os.path.dirname(output_path)
  if not os.path.isdir(output_dir):
    os.makedirs(output_dir)

  price_rules = {
    'roi': 0.3,
    'ad_cost': 5,
    'transfer_cost': 12
  }

  cfg = get_config()
  price_rules_cfg = cfg.get('price.rules.{}'.format(source.lower()), dict())
  for k, v in price_rules_cfg.items():
    price_rules[k] = round(float(v), 2)
  price_calculator = PriceCalculator(price_rules)

  price_calculator_pipeline = PriceCalculatorPipeline(price_calculator)
  base_attrs = {
    'min_shipping_days': min_shipping_days,
    'taxonomy_name': taxonomy_name,
    'merchant_id': merchant_id,
    'vendor_id': vendor_id,
    'tax_category_id': tax_category_id,
    'stock_location_id': stock_location_id,
    'shipping_category_id': shipping_category_id
  }

  with open(output_path, 'w+', encoding='utf-8', errors='ignore') as output_fh:
    with open(products_path, encoding='utf-8', errors='ignore') as fh:
      for line in fh:
        s = line.strip()
        if not s:
          continue

        prod = None
        try:
          prod = json.loads(s)
        except Exception as e:
          logger.exception(e)

        if not prod:
          continue

        product = price_calculator_pipeline(prod)
        if not product.get('price', 0):
          continue

        output_fh.write(json.dumps(product, ensure_ascii=False))


if __name__ == "__main__":
  format_products()
